@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,14 +21,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: sql.php,v 1.8 2004/09/18 19:21:12 alec Exp $
+ *  $Id: sql.php,v 1.19.2.1 2007/08/17 13:14:52 alec Exp $
  */
+
+include('sqllang.php');
  
-$layout['pagetitle'] = 'SQL';
+$layout['pagetitle'] = trans('SQL');
 
 if($query = $_POST['query'])
 {
-	$pagelimit = ( $_CONFIG['phpui']['sqlpanel_pagelimit'] ? $_CONFIG['lmsui']['sqlpanel_pagelimit'] : 50 );
+	$pagelimit = ( $CONFIG['phpui']['sqlpanel_pagelimit'] ? $CONFIG['phpui']['sqlpanel_pagelimit'] : 50 );
 	$page = (! $_GET['page'] ? 1 : $_GET['page']); 
 	$start = ($page - 1) * $pagelimit;
 	$words = array('SELECT','EXPLAIN','SHOW','DESCRIBE','ANALYZE','CHECK','OPTIMIZE','REPAIR','VACUUM');
@@ -37,9 +39,9 @@ if($query = $_POST['query'])
 	$rows = $LMS->DB->Execute($query);
 	$duration = getmicrotime() - $t;
 
-	if(sizeof($LMS->DB->errors)) 
+	if(sizeof($DB->errors)) 
 	{
-		$error['query'] = 'Zapytanie nie jest poprawne!';
+		$error['query'] = trans('Query is not correct!');
 		$SMARTY->assign('error', $error);
 		$SMARTY->assign('query', $query);
 		$SMARTY->display('sql.html');	
@@ -56,32 +58,40 @@ if($query = $_POST['query'])
 	{
 		unset($result);
 
-		switch($_CONFIG['database']['type'])
+		switch($CONFIG['database']['type'])
 		{
 		case 'postgres':
-			$cols = pg_num_fields($LMS->DB->_result);
+			$cols = pg_num_fields($DB->_result);
 			for($i=0; $i < $cols; $i++)
-				$colnames[] = pg_field_name($LMS->DB->_result, $i);
+				$colnames[] = pg_field_name($DB->_result, $i);
 		break;
 		case 'mysql':
-			$cols = mysql_num_fields($LMS->DB->_result);
+			$cols = mysql_num_fields($DB->_result);
 			for($i=0; $i < $cols; $i++)
-				$colnames[] = mysql_field_name($LMS->DB->_result, $i);
+				$colnames[] = mysql_field_name($DB->_result, $i);
 		break;
-		case 'sqlite':
-			$cols = sqlite_num_fields($LMS->DB->_result);
+		case 'mysqli':
+			$cols = mysqli_num_fields($DB->_result);
 			for($i=0; $i < $cols; $i++)
-				$colnames[] = sqlite_field_name($LMS->DB->_result, $i);
+			{
+				mysqli_field_seek($DB->_result, $i);
+				$finfo = mysqli_fetch_field($DB->_result);
+				$colnames[] = $finfo->name;
+			}
 		break;
 		}
-
+		
+		if($_GET['print'])
+			$classes = array(0 => 'grey', 1 => 'white');
+		else
+			$classes = array(0 => 'light', 1 => 'lucid');
 		$i = 0;
-		while($row = $LMS->DB->_driver_fetchrow_assoc())
+		while($row = $DB->_driver_fetchrow_assoc())
 		{
 			$i++;
 			if ( $i > $start && $i < ($start+$pagelimit+1) )
 			{
-				$result .= '<TR CLASS="LIGHT"><TD CLASS="BLEND">'.$i.'</TD>';
+				$result .= '<TR CLASS="'.$classes[$i%2].'"><TD CLASS="BLEND">'.$i.'</TD>';
 				foreach($colnames as $column)	
 				{
 					$result .= '<TD>'.nl2br(htmlspecialchars($row[$column])).'</TD>';
@@ -100,7 +110,7 @@ if($query = $_POST['query'])
 	$SMARTY->assign('colnames', $colnames);
 	$SMARTY->assign('executetime', $duration);
 	$SMARTY->assign('result', $result);
-	$layout['pagetitle'] = 'SQL - Wyniki zapytania';
+	$layout['pagetitle'] = trans('SQL - Query Results');
 }
 
 $SMARTY->assign('query', $query);
