@@ -4,8 +4,8 @@ struct ggnotify_module
 	MODULE base;
 
 	int uin;
-	unsigned char *passwd;	
-	unsigned char *ggtemplate;
+	char *passwd;	
+	char *ggtemplate;
 	int debuguin;
 	int limit;
 };
