@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB.php,v 1.7 2004/09/18 19:21:15 alec Exp $
+ *  $Id: LMSDB.php,v 1.14.2.1 2007/08/17 13:15:11 alec Exp $
  */
 
 /*
@@ -31,7 +31,7 @@
  * This file include required files and do some nasty things ;>
  */
 
-define(LMSDB_DIR,dirname(__FILE__));
+define('LMSDB_DIR',dirname(__FILE__));
 
 require_once(LMSDB_DIR.'/LMSDB_common.class.php');
 
@@ -53,4 +53,4 @@ function DBInit($dbtype,$dbhost,$dbuser,$dbpasswd,$dbname)
 	return FALSE;
 }
 
-?>
\ No newline at end of file
+?>
