@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_common.class.php,v 1.27 2004/09/18 19:21:15 alec Exp $
+ *  $Id: LMSDB_common.class.php,v 1.42.2.1 2007/08/17 13:15:11 alec Exp $
  */
 
 /*
@@ -30,8 +30,8 @@
 
 Class LMSDB_common
 {
-	var $_version = '1.5.0 Marduk';
-	var $_revision = '$Revision: 1.27 $';
+	var $_version = '1.10.2 Roham';
+	var $_revision = '$Revision: 1.42.2.1 $';
 	
 	// Driver powinien nadpisa t zmienn wartoci TRUE, eby
 	// funkcja inicjujca baze danych wiedziaa e driver si poprawnie
@@ -51,6 +51,7 @@ Class LMSDB_common
 	var $_result = NULL;
 
 	var $errors = array();
+	var $debug = FALSE;
 
 	function LMSDB_common()
 	{
@@ -60,8 +61,22 @@ Class LMSDB_common
 	
 	function Connect($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		// Inicjuje poczenie do bazy danych
-		return $this->_driver_connect($dbhost,$dbuser,$dbpasswd,$dbname);
+		if(method_exists($this, '_driver_shutdown'))
+			register_shutdown_function(array($this, '_driver_shutdown'));
+		
+		// Inicjuje poczenie do bazy danych, nie musimy zwraca
+		// dblinka na zewntrz gdy jest to niepotrzebne.
+		
+		if($this->_driver_connect($dbhost,$dbuser,$dbpasswd,$dbname))
+			return $this->_dblink;
+		else
+		{
+			$this->errors[] = array(
+					'query' => 'database connect',
+					'error' => $this->_driver_geterror(),
+					);
+			return FALSE;
+		}
 	}
 
 	function Destroy()
@@ -71,25 +86,25 @@ Class LMSDB_common
 
 	function Execute($query, $inputarray = NULL)
 	{
-	//	echo $this->_query_parser($query,$inputarray).'<HR>';
-		if(! $this->_driver_execute($this->_query_parser($query,$inputarray)))
-		{
+		if(! $this->_driver_execute($this->_query_parser($query, $inputarray)))
 			$this->errors[] = array(
 					'query' => $this->_query,
 					'error' => $this->_driver_geterror()
 					);
-		}
+		elseif($this->debug)
+			$this->errors[] = array(
+					'query' => $this->_query,
+					'error' => 'DEBUG: NOERROR'
+					);
 		return $this->_driver_affected_rows();
 	}
 
 	function GetAll($query = NULL, $inputarray = NULL)
 	{
-		// zwraca tablic z caym wynikiem
-	
 		if($query)
 			$this->Execute($query, $inputarray);
 
-		unset($result);
+		$result = NULL;
 
 		while($row = $this->_driver_fetchrow_assoc())
 			$result[] = $row;
@@ -102,7 +117,7 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
-		unset($result);
+		$result = NULL;
 
 		while($row = $this->_driver_fetchrow_assoc())
 			$result[$row[$key]] = $row;
@@ -123,7 +138,7 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
-		unset($result);
+		$result = NULL;
 
 		while($row = $this->_driver_fetchrow_num())
 			$result[] = $row[0];
@@ -136,13 +151,39 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
-		unset($result);
+		$result = NULL;
 
 		list($result) = $this->_driver_fetchrow_num();
 
 		return $result;
 	}
 
+	// with Exec() & FetchRow() we can do big results looping
+	// in less memory consumptive way than using GetAll() & foreach()
+	function Exec($query, $inputarray = NULL)
+	{
+		if(! $this->_driver_execute($this->_query_parser($query, $inputarray)))
+			$this->errors[] = array(
+					'query' => $this->_query,
+					'error' => $this->_driver_geterror()
+					);
+		elseif($this->debug)
+			$this->errors[] = array(
+					'query' => $this->_query,
+					'error' => 'DEBUG: NOERROR'
+					);
+		
+		if($this->_driver_num_rows())
+			return $this->_result;
+		else
+			return NULL;
+	}
+
+	function FetchRow($result)
+	{
+		return $this->_driver_fetchrow_assoc($result);
+	}
+	
 	function Concat()
 	{
 		return $this->_driver_concat(func_get_args());
@@ -168,16 +209,32 @@ Class LMSDB_common
 		return $this->_driver_committrans();
 	}
 
+	function LockTables($table)
+	{
+		return $this->_driver_locktables($table);
+	}
+
+	function UnLockTables()
+	{
+		return $this->_driver_unlocktables();
+	}
+
 	function GetDBVersion()
 	{
 		return $this->_driver_dbversion();
 	}
 
+	function GetLastInsertID($table = NULL)
+	{
+		return $this->_driver_lastinsertid($table);
+	}
+
 	function _query_parser($query, $inputarray = NULL)
 	{
 		// najpierw sparsujmy wszystkie specjalne meta mieci.
 		$query = eregi_replace('\?NOW\?',$this->_driver_now(),$query);
 		$query = eregi_replace('\?LIKE\?',$this->_driver_like(),$query);
+
 		if($inputarray)
 		{
 			$queryelements = explode("\0",str_replace('?',"?\0",$query));
