@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_mysql.class.php,v 1.25 2004/09/18 19:21:17 alec Exp $
+ *  $Id: LMSDB_driver_mysql.class.php,v 1.48.2.1 2007/08/17 13:15:11 alec Exp $
  */
 
 /*
@@ -33,10 +33,17 @@ class LMSDB_driver_mysql extends LMSDB_common
 	var $_loaded = TRUE;
 	var $_dbtype = 'mysql';
 
-	function LMSDB_driver_mysql($dbhost,$dbuser,$dbpasswd,$dbname)
+	function LMSDB_driver_mysql($dbhost, $dbuser, $dbpasswd, $dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.25 $').')';
-		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
+		if(!extension_loaded('mysql'))
+		        die('MySQL extension not loaded!');
+	
+		$this->_version .= ' ('.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).'/'.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.48.2.1 $').')';
+		$this->Connect($dbhost, $dbuser, $dbpasswd, $dbname);
+
+		if($this->_dblink)
+			if(version_compare($this->_driver_dbversion(), '5') < 0)
+				die('MySQL version not supported!');
 	}
 	
 	function _driver_dbversion()
@@ -44,9 +51,9 @@ class LMSDB_driver_mysql extends LMSDB_common
 		return mysql_get_server_info();
 	}
 
-	function _driver_connect($dbhost,$dbuser,$dbpasswd,$dbname)
+	function _driver_connect($dbhost, $dbuser, $dbpasswd, $dbname)
 	{
-		if($this->_dblink = mysql_connect($dbhost,$dbuser,$dbpasswd))
+		if($this->_dblink = @mysql_connect($dbhost,$dbuser,$dbpasswd))
 		{
 			$this->_dbhost = $dbhost;
 			$this->_dbuser = $dbuser;
@@ -59,19 +66,30 @@ class LMSDB_driver_mysql extends LMSDB_common
 		return $this->_dblink;
 	}
 
+	function _driver_shutdown()
+	{
+		$this->_loaded = FALSE;
+		// mysql_close($this->_dblink); - apparently, mysql_close() is automagicly called after end of the script...
+	}
+	
 	function _driver_geterror()
 	{
-		return mysql_error($this->_dblink);
+		if($this->_dblink)
+			return mysql_error($this->_dblink);
+		elseif($this->_query)
+			return 'We\'re not connected!';
+		else
+			return mysql_error();
 	}
 
 	function _driver_disconnect()
 	{
-		return mysql_close($this->_dblink);
+		return @mysql_close($this->_dblink);
 	}
 	
 	function _driver_selectdb($dbname)
 	{
-		if($result = mysql_select_db($dbname,$this->_dblink))
+		if($result = mysql_select_db($dbname, $this->_dblink))
 			$this->_dbname = $dbname;
 		return $result;
 	}
@@ -80,17 +98,17 @@ class LMSDB_driver_mysql extends LMSDB_common
 	{
 		$this->_query = $query;
 
-		if($this->_result = mysql_query($query,$this->_dblink))
+		if($this->_result = @mysql_query($query, $this->_dblink))
 			$this->_error = FALSE;
 		else
 			$this->_error = TRUE;
 		return $this->_result;
 	}
 
-	function _driver_fetchrow_assoc()
+	function _driver_fetchrow_assoc($result = NULL)
 	{
 		if(! $this->_error)
-			return mysql_fetch_array($this->_result,MYSQL_ASSOC);
+			return mysql_fetch_array($result ? $result : $this->_result, MYSQL_ASSOC);
 		else
 			return FALSE;
 	}
@@ -98,7 +116,7 @@ class LMSDB_driver_mysql extends LMSDB_common
 	function _driver_fetchrow_num()
 	{
 		if(! $this->_error)
-			return mysql_fetch_array($this->_result,MYSQL_NUM);
+			return mysql_fetch_array($this->_result, MYSQL_NUM);
 		else
 			return FALSE;
 	}
@@ -110,6 +128,14 @@ class LMSDB_driver_mysql extends LMSDB_common
 		else
 			return FALSE;
 	}
+
+	function _driver_num_rows()
+	{
+		if(! $this->_error)
+			return mysql_num_rows($this->_result);
+		else
+			return FALSE;
+	}
 	
 	function _driver_now()
 	{
@@ -123,14 +149,15 @@ class LMSDB_driver_mysql extends LMSDB_common
 
 	function _driver_concat($input)
 	{
-		$return = implode(', ',$input);
+		$return = implode(', ', $input);
 		return 'CONCAT('.$return.')';
 	}
 
 	function _driver_listtables()
 	{
-		$this->_result = mysql_list_tables($this->_dbname,$this->_dblink);
-		return $this->GetCol();
+		return $this->GetCol('SELECT table_name FROM information_schema.tables
+	                        WHERE table_type = ? AND table_schema = ?',
+				array('BASE TABLE', $this->_dbname));
 	}
 
 	function _driver_begintrans()
@@ -143,6 +170,24 @@ class LMSDB_driver_mysql extends LMSDB_common
 	{
 		return TRUE;
 	}
+
+	function _driver_locktables($table)
+	{
+		if(is_array($table))
+			$this->Execute('LOCK TABLES '.implode(', ', $table));
+		else
+			$this->Execute('LOCK TABLES '.$table);		
+	}
+
+	function _driver_unlocktables()
+	{
+		$this->Execute('UNLOCK TABLES');
+	}
+        
+	function _driver_lastinsertid($table = NULL)
+        {
+	        return $this->GetOne('SELECT LAST_INSERT_ID()');
+	}
 }
 
 ?>
