@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_postgres.class.php,v 1.19 2004/09/18 19:21:17 alec Exp $
+ *  $Id: LMSDB_driver_postgres.class.php,v 1.38.2.1 2007/08/17 13:15:11 alec Exp $
  */
 
 /*
@@ -35,14 +35,16 @@ class LMSDB_driver_postgres extends LMSDB_common
 
 	function LMSDB_driver_postgres($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.19 $').')';
+		if(!extension_loaded('pgsql'))
+			die('PostgreSQL extension not loaded!');
+
+		$this->_version .= ' ('.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).'/'.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.38.2.1 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
 	function _driver_dbversion()
 	{
-		list($var1, $var2) = explode(' ',$this->GetOne("SELECT version()"));
-		return $var2;
+		return $this->GetOne("SELECT substring(substring(version() from 1+position(' ' in version())) for position(' ' in substring(version() from 1+position(' ' in version())))-1)");
 	}
 
 	function _driver_connect($dbhost,$dbuser,$dbpasswd,$dbname)
@@ -63,6 +65,7 @@ class LMSDB_driver_postgres extends LMSDB_common
 		}
 		else
 			$this->_error = TRUE;
+
 		return $this->_dblink;
 	}
 
@@ -79,6 +82,7 @@ class LMSDB_driver_postgres extends LMSDB_common
 	function _driver_execute($query)
 	{
 		$this->_query = $query;
+
 		if($this->_result = pg_query($this->_dblink,$query))
 			$this->_error = FALSE;
 		else
@@ -86,10 +90,10 @@ class LMSDB_driver_postgres extends LMSDB_common
 		return $this->_result;
 	}
 
-	function _driver_fetchrow_assoc()
+	function _driver_fetchrow_assoc($result = NULL)
 	{
 		if(! $this->_error)
-			return pg_fetch_array($this->_result,NULL,PGSQL_ASSOC);
+			return pg_fetch_array($result ? $result : $this->_result,NULL, PGSQL_ASSOC);
 		else
 			return FALSE;
 	}
@@ -110,6 +114,14 @@ class LMSDB_driver_postgres extends LMSDB_common
 			return FALSE;
 	}
 
+	function _driver_num_rows()
+	{
+		if(! $this->_error)
+			return pg_num_rows($this->_result);
+		else
+			return FALSE;
+	}
+
 	function _driver_now()
 	{
 		return 'EXTRACT(EPOCH FROM CURRENT_TIMESTAMP(0))';
@@ -122,8 +134,7 @@ class LMSDB_driver_postgres extends LMSDB_common
 
 	function _driver_concat($input)
 	{
-		$return = implode(' || ',$input);
-		return $return;
+		return implode(' || ',$input);
 	}
 
 	function _driver_listtables()
@@ -140,6 +151,24 @@ class LMSDB_driver_postgres extends LMSDB_common
 	{
 		return $this->Execute('COMMIT');
 	}
+
+	function _driver_locktables($table)
+        {
+	        if(is_array($table))
+		        $this->Execute('LOCK '.implode(', ', $table));
+		else
+		        $this->Execute('LOCK '.$table);
+	}
+
+	function _driver_unlocktables()
+	{
+		return TRUE;
+	}
+																		
+	function _driver_lastinsertid($table)
+	{
+               return $this->GetOne('SELECT currval(\''.$table.'_id_seq\')');
+	}       
 }
 
 ?>
