@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Sysinfo.class.php,v 1.16 2004/09/18 19:21:18 alec Exp $
+ *  $Id: Sysinfo.class.php,v 1.26.2.1 2007/08/17 13:15:11 alec Exp $
  */
 
 /*
@@ -33,12 +33,12 @@ class Sysinfo {
 	
 	function get_sysinfo()
 	{
-		$return[hostname] = $this->hostname();
-		$return[uptime] = $this->uptime();
-		$return[kernel] = $this->kernel();
-		$return[users] = $this->users();
-		$return[loadavg] = $this->loadavg();
-		$return[phpversion] = phpversion();
+		$return['hostname'] = $this->hostname();
+		$return['uptime'] = $this->uptime();
+		$return['kernel'] = $this->kernel();
+		$return['users'] = $this->users();
+		$return['loadavg'] = $this->loadavg();
+		$return['phpversion'] = phpversion();
 		return $return;
 	}
 
@@ -100,22 +100,23 @@ class Sysinfo {
 	{
 		switch(PHP_OS)
 		{
-			case "Linux":
-				exec("hostname -f",$return);
+			case 'Linux':
+				exec('hostname -f',$return);
 				$hostname=$return[0];
 				break;
-			case "FreeBSD":
-			case "OpenBSD":
-			case "NetBSD":
-			case "WinNT":
-				exec("hostname",$return);
+			case 'FreeBSD':
+			case 'OpenBSD':
+			case 'NetBSD':
+			case 'Darwin':
+			case 'WinNT':
+				exec('hostname',$return);
 				$hostname=$return[0];
 				break;
 			default:
-				$return = "nieznany, ".PHP_OS;
+				$return = trans('unknown OS ($0)',PHP_OS);
 		}
-		if($hostname=="")
-			$hostname="N.A.";
+		if($hostname=='')
+			$hostname='N.A.';
 		return $hostname;
 	}
 		
@@ -127,31 +128,32 @@ class Sysinfo {
 				
 		switch (PHP_OS)
 		{
-			case "Linux":
+			case 'Linux':
 				$fd = fopen('/proc/uptime', 'r');
 				$ar_buf = split(' ', fgets($fd, 4096));
 				fclose($fd);
 				$sys_ticks = trim($ar_buf[0]);
 				$result = uptimef($sys_ticks);
 			break;
-			case "FreeBSD":
+			case 'FreeBSD':
 				$s = explode(' ', $this->bsd_grab_key('kern.boottime'));
 				$a = ereg_replace('{ ', '', $s[3]);
 				$sys_ticks = time() - $a;
 				$result = uptimef($sys_ticks);
 			break;
-			case "NetBSD":
+			case 'Darwin':
+			case 'NetBSD':
 				$a = $this->bsd_grab_key('kern.boottime');
 				$sys_ticks = time() - $a;
 				$result = uptimef($sys_ticks);
 			break;
-			case "OpenBSD":
+			case 'OpenBSD':
 				$a = $this->bsd_grab_key('kern.boottime');
 				$sys_ticks = time() - $a;
 				$result = uptimef($sys_ticks);
 			break;
 			default:
-				$result = "nieznany os (".PHP_OS.")";
+				$result = trans('unknown OS ($0)',PHP_OS);
 			break;
 		}
 		return $result;
@@ -161,13 +163,16 @@ class Sysinfo {
 	{
 		switch(PHP_OS)
 		{
-			
-			case "WinNT":
+			case 'WinNT':
 				$result = 'Windows NT/2000/XP N.A.';
 			break;
-			case "Win32":
+			case 'Win32':
 				$result = 'Windows 95/98/ME N.A.';
 			break;
+			case 'Darwin':
+				$result = execute_program('sw_vers', '-productName');
+				$result .= ' '. execute_program('sw_vers', '-productVersion');
+			break;
 			default:
 				$result = $this->execute_program('uname','-s -r');
 			break;
@@ -182,9 +187,9 @@ class Sysinfo {
 	{
 		switch(PHP_OS)
 		{
-			case "WinNT":
-			case "Win32":
-				$result = "N.A.";
+			case 'WinNT':
+			case 'Win32':
+				$result = 'N.A.';
 			default:
 				$who = split('=', execute_program('who', '-q'));
 				$result = $who[1];
@@ -193,14 +198,13 @@ class Sysinfo {
 		if($result=='')
 			$result = 'N.A.';
 		return $result;
-
 	}
 
 	function loadavg()
 	{
 		switch(PHP_OS)
 		{
-			case "Linux":
+			case 'Linux':
 				if ($fd = fopen('/proc/loadavg', 'r'))
 				{
 					$results = split(' ', fgets($fd, 4096));
@@ -209,9 +213,10 @@ class Sysinfo {
 				else
 					$results = array('N.A.','N.A.','N.A.');
 			break;
-			case "FreeBSD":
-			case "NetBSD":
-			case "OpenBSD":			
+			case 'Darwin':
+			case 'FreeBSD':
+			case 'NetBSD':
+			case 'OpenBSD':			
 				$s = $this->bsd_grab_key('vm.loadavg');
 				$s = ereg_replace('{ ', '', $s);
 				$s = ereg_replace(' }', '', $s);
