@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,31 +21,44 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: checkip.php,v 1.17 2004/09/18 19:21:18 alec Exp $
+ *  $Id: checkip.php,v 1.27.2.2 2007/09/28 06:34:24 alec Exp $
  */
 
-// Sprawdzenie czy poczenie z dozwolonego IP.
+// Checking if connection is from allowed IP
 
-if($_CONFIG['phpui']['allow_from'])
+if(!empty($CONFIG['phpui']['allow_from']))
 {
-	// usumy prefix ipv6 jak jest
+	// delete ipv6 prefix if it's present: 
 	
 	$ipaddr = str_replace('::ffff:','',$_SERVER['REMOTE_ADDR']);
 
-	$allowedlist = explode(',',$_CONFIG['phpui']['allow_from']);
+	$allowedlist = explode(',',$CONFIG['phpui']['allow_from']);
+
+	$isin = FALSE;
 
 	foreach($allowedlist as $value)
 	{
-		list($net,$mask) = split('/',$value);
-		$net=trim($net);
-		$mask=trim($mask);
+		$net = '';
+		$mask = '';
+		
+		if(strpos($value, '/')===FALSE)
+			$net = $value;
+		else
+			list($net, $mask) = explode('/', $value);
+		
+		$net = trim($net);
+		$mask = trim($mask);
+
 		if($mask == '')
-			$mask = '32';
-		if($mask >= 0 || $mask <= 32)
+			$mask = '255.255.255.255';
+		elseif(is_numeric($mask))
 			$mask = prefix2mask($mask);
-	
-		if(isipinstrict($ipaddr,$net,$mask))
+
+		if(isipinstrict($ipaddr, $net, $mask))
+		{
 			$isin = TRUE;
+			break;
+		}
 	}
 
 	if(!$isin)
