@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,26 +21,42 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: upgradedb.php,v 1.28 2004/09/18 19:21:20 alec Exp $
+ *  $Id: upgradedb.php,v 1.116.2.1 2007/08/17 13:15:13 alec Exp $
  */
 
-define(DBVERSION, '2004090800'); // here should be always the newest version of database!
-// it placed here to avoid read disk every time when we call this file.
+define('DBVERSION', '2007080100'); // here should be always the newest version of database!
+				 // it placed here to avoid read disk every time when we call this file.
 
 /*
  * This file contains procedures for upgradeing automagicly database.
  */
 
+function getdir($pwd = './', $pattern = '^.*$')
+{
+	if ($handle = @opendir($pwd))
+	{
+		while (($file = readdir($handle)) !== FALSE)
+			if(ereg($pattern,$file))
+				$files[] = $file;
+		closedir($handle);
+	}
+	return $files;
+}
+
 if($dbversion = $DB->GetOne('SELECT keyvalue FROM dbinfo WHERE keytype = ?',array('dbversion')))
 	if(DBVERSION > $dbversion)
 	{
-		$upgradelist = getdir($_LIB_DIR.'/upgradedb/', '^'.$_DBTYPE.'.[0-9]{10}.php$');
+		set_time_limit(0);
+		$lastupgrade = $dbversion;
+		$_dbtype = $CONFIG['database']['type'] == 'mysqli' ? 'mysql' : $CONFIG['database']['type'];
+		
+		$upgradelist = getdir(LIB_DIR.'/upgradedb/', '^'.$_dbtype.'.[0-9]{10}.php$');
 		if(sizeof($upgradelist))
 			foreach($upgradelist as $upgrade)
 			{
-				$upgradeversion = ereg_replace('^'.$_DBTYPE.'.([0-9]{10}).php$','\1',$upgrade);
+				$upgradeversion = ereg_replace('^'.$_dbtype.'.([0-9]{10}).php$','\1',$upgrade);
 				
-				if($upgradeversion > $dbversion)
+				if($upgradeversion > $dbversion && $upgradeversion <= DBVERSION)
 					$pendingupgrades[] = $upgradeversion;
 			}
 			
@@ -48,12 +64,16 @@ if($dbversion = $DB->GetOne('SELECT keyvalue FROM dbinfo WHERE keytype = ?',arra
 		{
 			sort($pendingupgrades);
 			foreach($pendingupgrades as $upgrade)
-			{
-				include($_LIB_DIR.'/upgradedb/'.$_DBTYPE.'.'.$upgrade.'.php');
+			{	
+				include(LIB_DIR.'/upgradedb/'.$_dbtype.'.'.$upgrade.'.php');
+				if(!sizeof($DB->errors))
+					$lastupgrade = $upgrade;
+				else
+					break;
 			}
 		}
 	}
 
-$layout['dbschversion'] = DBVERSION;
+$layout['dbschversion'] = isset($lastupgrade) ? $lastupgrade : DBVERSION;
 
 ?>
