@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.4-cvs
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: postgres.2004090700.php,v 1.2 2004/09/18 19:21:22 alec Exp $
+ *  $Id: postgres.2004090700.php,v 1.6 2007/01/07 08:10:03 alec Exp $
  */
 
+$DB->BeginTrans();
 $DB->Execute("
-    BEGIN;
     CREATE INDEX cash_userid_idx ON cash(userid);
     UPDATE dbinfo SET keyvalue = '2004090700' WHERE keytype = 'dbversion';
-    COMMIT;
 ");
+$DB->CommitTrans();
 
 ?>
