@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,19 +21,18 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: postgres.2004090800.php,v 1.3 2004/09/18 19:21:22 alec Exp $
+ *  $Id: postgres.2004090800.php,v 1.9.2.1 2007/08/17 13:15:18 alec Exp $
  */
 
+$DB->BeginTrans();
 $DB->Execute("
-    BEGIN;
-
     ALTER TABLE users ADD COLUMN pin integer;
     UPDATE users SET pin=random()*10 + random()*100 + random()*1000 + random()*10000 + random()*100000-1;
     ALTER TABLE users ALTER pin SET DEFAULT 0;
     ALTER TABLE users ALTER pin SET NOT NULL;
     
     UPDATE dbinfo SET keyvalue = '2004090800' WHERE keytype = 'dbversion';
-    COMMIT;
 ");
+$DB->CommitTrans();
 
 ?>
