@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,10 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancedel.php,v 1.2 2004/09/18 19:21:24 alec Exp $
+ *  $Id: balancedel.php,v 1.12.2.1 2007/08/17 13:15:20 alec Exp $
  */
 
-if (sizeof($_POST['marks']))
+if($_GET['id'])
+{
+	$LMS->DelBalance($_GET['id']);
+}
+elseif(sizeof($_POST['marks']))
 {
 	foreach($_POST['marks'] as $markid => $junk)
 		if ($junk)
@@ -36,6 +40,6 @@ if (sizeof($_POST['marks']))
 	}
 }
 
-header("Location: ?".$_SESSION['backto']);
+header('Location: ?'.$SESSION->get('backto'));
 
 ?>
