@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,38 +21,41 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: choosemac.php,v 1.16 2004/09/18 19:21:24 alec Exp $
+ *  $Id: choosemac.php,v 1.23.2.3 2007/10/02 06:54:46 alec Exp $
  */
 
-$layout['pagetitle'] = "Wybierz adres MAC";
+$layout['pagetitle'] = trans('Select MAC address');
 
-$p = $_GET['p'];
-$netid = $_POST['netid'];
+$p = isset($_GET['p']) ? $_GET['p'] : '';
+$js = '';
 
-if(!isset($p))
-	$js = "var targetfield = window.opener.targetfield;";
-if($p == "main")
-	$js = "var targetfield = parent.targetfield;";
-
-if($p == "main")
+if(!$p)
+	$js = 'var targetfield = window.opener.targetfield;';
+elseif($p == 'main')
 {
+	$js = 'var targetfield = parent.targetfield;';
+
 	$maclist = $LMS->GetMACs();
-	if($LMS->CONFIG['phpui']['arpd_servers'])
+
+	if(isset($CONFIG['phpui']['arpd_servers']) && $CONFIG['phpui']['arpd_servers'])
 	{
-		$servers = split(' ',eregi_replace("[\t ]+"," ",$LMS->CONFIG['phpui']['arpd_servers']));
+		$servers = explode(' ', eregi_replace("[\t ]+"," ",$CONFIG['phpui']['arpd_servers']));
 		foreach($servers as $server)
 		{
-			list($addr,$port) = split(':',$server);
-			if($port == "")
-				$port = 1029;
-			$maclist = array_merge($maclist,$LMS->GetRemoteMACs($addr,$port));
+			$res = explode(':', $server);
+			if(!isset($res[1]) || $res[1] == '')
+				$res[1] = 1029;
+			
+			$remote = $LMS->GetRemoteMACs($res[0], $res[1]);
+			$maclist = array_merge($maclist, $remote);
 		}
 	}
+	
 	$SMARTY->assign('maclist',$maclist);
 }
 
-$SMARTY->assign('part',$p);
-$SMARTY->assign('js',$js);
+$SMARTY->assign('part', $p);
+$SMARTY->assign('js', $js);
 $SMARTY->display('choosemac.html');
 
 ?>
