@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,43 +21,40 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: chpasswd.php,v 1.16 2004/09/18 19:21:24 alec Exp $
+ *  $Id: chpasswd.php,v 1.32.2.1 2007/08/17 13:15:21 alec Exp $
  */
 
-$passwd = $_POST['passwd'];
+$id = $AUTH->id;
 
-$id = $SESSION->id;
-
-if($LMS->AdminExists($id))
+if($LMS->UserExists($id))
 {
-	if(isset($passwd))
+	if(isset($_POST['passwd']))
 	{
-		if($passwd['passwd'] == "" || $passwd['confirm'] == "")
-			$error['password'] .= "Haso nie moe by puste!<BR>";
+		$passwd = $_POST['passwd'];
 		
-		if($passwd['passwd'] != $passwd['confirm'])
-			$error['password'] .= "Podane hasa si rni!";
+		if($passwd['passwd'] == '' || $passwd['confirm'] == '')
+			$error['password'] = trans('Empty passwords are not allowed!');
+		elseif($passwd['passwd'] != $passwd['confirm'])
+			$error['password'] = trans('Passwords does not match!');
 		
 		if(!$error)
 		{
-			$LMS->SetAdminPassword($id,$passwd['passwd']);
-			header("Location: ?m=welcome");
+			$LMS->SetUserPassword($id,$passwd['passwd']);
+			header('Location: ?'.$SESSION->get('backto'));
 		}
 	}
 
-	$passwd['realname'] = $LMS->GetAdminName($id);
 	$passwd['id'] = $id;
-	$layout['pagetitle'] = "Zmiana hasa";
-	$SMARTY->assign('error',$error);
-	$SMARTY->assign('passwd',$passwd);
-	$SMARTY->assign('target',"?m=chpasswd");
-	$SMARTY->display('adminpasswd.html');
+	$layout['pagetitle'] = trans('Password Change');
 
+	$SMARTY->assign('passwd', $passwd);
+	$SMARTY->assign('error', $error);
+	$SMARTY->assign('target', '?m=chpasswd');
+	$SMARTY->display('userpasswd.html');
 }
 else
 {
-	header("Location: ?m=".$_SESSION['lastmodule']);
-	die;
+	$SESSION->redirect('?m='.$SESSION->get('lastmodule'));
 }
 
-?>
\ No newline at end of file
+?>
