@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: confirm.php,v 1.2 2004/09/18 19:21:24 alec Exp $
+ *  $Id: confirm.php,v 1.8.2.1 2007/08/17 13:15:21 alec Exp $
  */
 
-$layout['pagetitle'] = 'Pytanie';
+$layout['pagetitle'] = trans('Question');
 
 $SMARTY->assign('text', stripslashes($_GET['text']));
 $SMARTY->assign('href', $_GET['link']);
