@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,11 +21,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbnew.php,v 1.17 2004/09/18 19:21:25 alec Exp $
+ *  $Id: dbnew.php,v 1.30.2.1 2007/08/17 13:15:23 alec Exp $
  */
 
-$LMS->DatabaseCreate();
+set_time_limit(0);
 
-header("Location: ?m=".$_SESSION['lastmodule']);
+if (isset($_GET['gz']))
+	$LMS->DatabaseCreate(TRUE);
+else
+	$LMS->DatabaseCreate();
 
-?>
\ No newline at end of file
+header('Location: ?m=dblist');
+
+?>
