@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: logout.php,v 1.23 2004/09/18 19:21:26 alec Exp $
+ *  $Id: logout.php,v 1.30.2.1 2007/08/17 13:15:25 alec Exp $
  */
 
 if($_GET['is_sure'] == '1') 
 {
-	$SESSION->LogOut();
+	$AUTH->LogOut();
 	header('Location: ?m=welcome');
 } else
-	header('Location: ?m='.$_SESSION['lastmodule']);    
+	header('Location: ?m='.$SESSION->get('lastmodule'));
 
 ?>
