@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netcmp.php,v 1.22 2004/09/18 19:21:26 alec Exp $
+ *  $Id: netcmp.php,v 1.34.2.1 2007/08/17 13:15:25 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
 {
-	header("Location: ?m=netlist");
-	die;
+	$SESSION->redirect('?m=netlist');
 }
 
 $network['name'] = $LMS->GetNetworkName($_GET['id']);
@@ -35,15 +34,14 @@ $network['name'] = $LMS->GetNetworkName($_GET['id']);
 if($_GET['is_sure'])
 {
 	$LMS->NetworkCompress($_GET['id']);
-	header("Location: ?m=".$_SESSION['lastmodule']."&id=".$_GET['id']);
-	die;
+	$SESSION->redirect('?m='.$SESSION->get('lastmodule').'&id='.$_GET['id']);
 }else{
-	$layout['pagetitle'] = "Porzdkowanie sieci ".strtoupper($network['name']);
+	$layout['pagetitle'] = trans('Readdressing Network $0', strtoupper($network['name']));
 	$SMARTY->display('header.html');
-	echo "<H1>Porzdkowanie sieci ".strtoupper($network['name'])."</H1>";
-	echo "<p>Czy jeste pewien e chcesz uporzdkowa t sie?</p>";
-	echo "<a href=\"?m=netcmp&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien</A>";
+	echo '<H1>'.trans('Readdressing network $0', strtoupper($network['name'])).'</H1>';
+	echo '<P>'.trans('Are you sure, you want to reorder that network?').'</P>';
+	echo '<A href="?m=netcmp&id='.$_GET['id'].'&is_sure=1">'.trans('Yes, I am sure.').'</A>';
 	$SMARTY->display('footer.html');
 }
 
-?>
\ No newline at end of file
+?>
