@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,17 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdel.php,v 1.23 2004/09/18 19:21:26 alec Exp $
+ *  $Id: netdel.php,v 1.34.2.1 2007/08/17 13:15:25 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
 {
-	header("Location: ?m=netlist");
-	die;
+	$SESSION->redirect('?m=netlist');
 }
 
 $network = $LMS->GetNetworkRecord($_GET['id']);
-$networks = $LMS->GetNetworks();
 
 if($network['assigned'])
 	$error['delete'] = TRUE;
@@ -41,22 +39,25 @@ if(!$error)
 	if($_GET['is_sure'])
 	{
 		$LMS->NetworkDelete($network['id']);
-		header("Location: ?m=".$_SESSION['lastmodule']."&id=".$_GET['id']);
-		die;
-	}else{
-		$layout['pagetitle'] = "Usunicie sieci ".strtoupper($network['name']);
+		$SESSION->redirect('?m='.$SESSION->get('lastmodule').'&id='.$_GET['id']);
+	}
+	else
+	{
+		$layout['pagetitle'] = trans('Removing network $0', strtoupper($network['name']));
 		$SMARTY->display('header.html');
-		echo "<H1>Usunicie sieci ".strtoupper($network['name'])."</H1>";
-		echo "<p>Czy jeste pewien e chcesz usun t sie?</p>";
-		echo "<a href=\"?m=netdel&id=".$network['id']."&is_sure=1\">Tak, jestem pewien</A>";
+		echo '<H1>'.$layout['pagetitle'].'</H1>';
+		echo '<P>'.trans('Are you sure, you want to delete that network?').'</P>';
+		echo '<A href="?m=netdel&id='.$network['id'].'&is_sure=1">'.trans('Yes, I am sure.').'</A>';
 		$SMARTY->display('footer.html');
 	}
-}else{
-	$layout['pagetitle'] = "Informacja o sieci";
+}
+else
+{
+	$layout['pagetitle'] = trans('Info Network: $0', $network['name']);
 	$SMARTY->assign('network',$network);
-	$SMARTY->assign('networks',$networks);
+	$SMARTY->assign('networks', $LMS->GetNetworks());
 	$SMARTY->assign('error',$error);
 	$SMARTY->display('netinfo.html');
 }
 
-?>
\ No newline at end of file
+?>
