@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,35 +21,32 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevadd.php,v 1.10 2004/09/18 19:21:26 alec Exp $
+ *  $Id: netdevadd.php,v 1.18.2.1 2007/08/17 13:15:25 alec Exp $
  */
 
-$netdevdata = $_POST['netdev'];
+if(isset($_POST['netdev']))
+{
+	$netdevdata = $_POST['netdev'];
 
-if(isset($netdevdata)) {
-	// Jakby to dziaao to by byo mio... :P
-	//if($netdevdata['ports'] !="" && !eregi("^[0-9]{,4}$",$netdevdata['ports']))
-        //        $error['ports'] = "Podana ilo portw jest bdna!";
-	if($netdevdata['ports'] =='')
+	if($netdevdata['ports'] == '')
 		$netdevdata['ports'] = 0;
 	if($netdevdata['name'] == '')
-		$error['name'] = 'Pole nazwa nie moe by puste!';
+		$error['name'] = trans('Device name is required!');
 	elseif(strlen($netdevdata['name'])>32)
-		$error['name'] = 'Podana nazwa jest za duga!';
+		$error['name'] = trans('Device name is too long (max.32 characters)!');
 
         if(!$error)
         {
-	    $netdevid=$LMS->NetDevAdd($netdevdata);
-	    header('Location: ?m=netdevinfo&id='.$netdevid);
-	    die;
+	    $netdevid = $LMS->NetDevAdd($netdevdata);
+	    $SESSION->redirect('?m=netdevinfo&id='.$netdevid);
         }
+	
+	$SMARTY->assign('error', $error);
+	$SMARTY->assign('netdev', $netdevdata);
 }
 		
+$layout['pagetitle'] = trans('New Device');
 
-$layout['pagetitle'] = 'Nowe urzdzenie';
-
-$SMARTY->assign('error',$error);
-$SMARTY->assign('netdev',$netdevdata);
 $SMARTY->display('netdevadd.html');
 
 ?>
