@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,40 +21,33 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevdel.php,v 1.10 2004/09/18 19:21:26 alec Exp $
+ *  $Id: netdevdel.php,v 1.22.2.1 2007/08/17 13:15:25 alec Exp $
  */
 
 if(! $LMS->NetDevExists($_GET['id']))
 {
-	header('Location: ?m=netdevlist');
-	die;
+	$SESSION->redirect('?m=netdevlist');
 }		
 
-$layout['pagetitle'] = "Usunicie urzdzenia ID: ".sprintf("%04d",$_GET['id']);
+$layout['pagetitle'] = trans('Deletion of Device with ID: $0',sprintf('%04d',$_GET['id']));
 $SMARTY->assign('netdevid',$_GET['id']);
 
 if($LMS->CountNetDevLinks($_GET['id'])>0)
 {
-	$body = "<H1>".$layout['pagetitle']."</H1>";
-	$body .= "<P>Nie mona usun urzdzenia ktre jest podczone do innych urzdze lub komputerw.</P>";
+	$body = '<P>'.trans('Device connected to other device or node can\'t be deleted.').'</P>';
 }else{
     if($_GET['is_sure']!=1)
     {
-	    $body = "<H1>".$layout['pagetitle']."</H1>";
-	    $body .= "<P>Czy jeste pewien e chcesz usun urzdzenie?</P>"; 
-	    $body .= "<P><A HREF=\"?m=userdel&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien.</A></P>";
+	    $body = '<P>'.trans('Are you sure, you want to delete that device?').'</P>'; 
+	    $body .= '<P><A HREF="?m=customerdel&id='.$_GET['id'].'&is_sure=1">'.trans('Yes, I am sure.').'</A></P>';
     }else{
-	    header("Location: ?m=netdevlist");
-	    $body = "<H1>".$layout['pagetitle']."</H1>";
-	    $body .= "<P>Urzdzenie zostao usunite.</P>";
+	    header('Location: ?m=netdevlist');
+	    $body = '<P>'.trans('Device has been deleted.').'</P>';
 	    $LMS->DeleteNetDev($_GET['id']);
     }
 }
 	
-
-$SMARTY->display('header.html');
 $SMARTY->assign('body',$body);
 $SMARTY->display('dialog.html');
-$SMARTY->display('footer.html');
 
 ?>
