@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,38 +21,35 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevlist.php,v 1.11 2004/09/18 19:21:26 alec Exp $
+ *  $Id: netdevlist.php,v 1.22.2.1 2007/08/17 13:15:25 alec Exp $
  */
 
-$layout['pagetitle'] = "Osprzt sieciowy";
-
-$_SESSION['backto']=$_SERVER['QUERY_STRING'];
-
+$layout['pagetitle'] = trans('Network Devices');
 
 if(!isset($_GET['o']))
-	$o = $_SESSION['ndlo'];
+	$SESSION->restore('ndlo', $o);
 else
 	$o = $_GET['o'];
-$_SESSION['ndlo'] = $o;
+$SESSION->save('ndlo', $o);
 
 $netdevlist = $LMS->GetNetDevList($o);
-//$nodelist = $LMS->GetNodeList($o);
 $listdata['total'] = $netdevlist['total'];
 $listdata['order'] = $netdevlist['order'];
 $listdata['direction'] = $netdevlist['direction'];
-
 unset($netdevlist['total']);
 unset($netdevlist['order']);
 unset($netdevlist['direction']);
 
-if (isset($_SESSION['nlp']) && !isset($_GET['page']))
-        $_GET['page'] = $_SESSION['nlp'];
+if(!isset($_GET['page']))
+        $SESSION->restore('ndlp', $_GET['page']);
 	
 $page = (! $_GET['page'] ? 1 : $_GET['page']);
-$pagelimit = (! $LMS->CONFIG['phpui']['nodelist_pagelimit'] ? $listdata['total'] : $LMS->CONFIG['phpui']['nodelist_pagelimit']);
+$pagelimit = (! $CONFIG['phpui']['nodelist_pagelimit'] ? $listdata['total'] : $CONFIG['phpui']['nodelist_pagelimit']);
 $start = ($page - 1) * $pagelimit;
 
-$_SESSION['nlp'] = $page;
+$SESSION->save('ndlp', $page);
+
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('page',$page);
 $SMARTY->assign('pagelimit',$pagelimit);
