@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,25 +21,26 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netinfo.php,v 1.28 2004/09/18 19:21:27 alec Exp $
+ *  $Id: netinfo.php,v 1.39.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
 {
-	header("Location: ?m=netlist");
-	die;
+	$SESSION->redirect('?m=netlist');
 }
 
-if (isset($_SESSION['ntlp'][$_GET['id']]) && !isset($_GET['page']))
-	$_GET['page'] = $_SESSION['ntlp'][$_GET['id']];
+$page = isset($_GET['page']) ? $_GET['page'] : 1;
 
-$_SESSION['ntlp'][$_GET['id']] = $_GET['page'];
+if($SESSION->is_set('ntlp.'.$_GET['id']) && !isset($_GET['page']))
+	$SESSION->restore('ntlp.'.$_GET['id'], $page);
 
-$network = $LMS->GetNetworkRecord($_GET['id'],$_GET['page'],1024);
+$SESSION->save('ntlp.'.$_GET['id'], $page);
 
-$layout['pagetitle'] = "Informacja o sieci: ".$network['name'];
+$network = $LMS->GetNetworkRecord($_GET['id'], $page, $CONFIG['phpui']['networkhosts_pagelimit']);
 
-$SMARTY->assign('network',$network);
+$layout['pagetitle'] = trans('Info Network: $0', $network['name']);
+
+$SMARTY->assign('network', $network);
 $SMARTY->display('netinfo.html');
 
 ?>
