@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,22 +21,23 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netlist.php,v 1.26 2004/09/18 19:21:27 alec Exp $
+ *  $Id: netlist.php,v 1.35.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
-$layout['pagetitle'] = "Sieci IP";
+$layout['pagetitle'] = trans('IP Networks');
 
 $netlist = $LMS->GetNetworkList();
 
 $listdata['size'] = $netlist['size'];
 $listdata['assigned'] = $netlist['assigned'];
+$listdata['online'] = $netlist['online'];
 
-unset($netlist['assigned'], $netlist['size'], $netlist['total']);
-
+unset($netlist['assigned']);
+unset($netlist['size']);
+unset($netlist['online']);
 $listdata['total'] = sizeof($netlist);
 
 $SMARTY->assign('listdata',$listdata);
-$SMARTY->assign('netadd',$netadd);
 $SMARTY->assign('netlist',$netlist);
 $SMARTY->display('netlist.html');
 
