@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,16 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netremap.php,v 1.23 2004/09/18 19:21:27 alec Exp $
+ *  $Id: netremap.php,v 1.32.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id'])||!$LMS->NetworkExists($_GET['mapto']))
 {
-	header("Location: ?m=netlist");
-	die;
+	$SESSION->redirect('?m=netlist');
 }
 
-$network['source'] = $LMS->GetNetworkRecord($_GET['id'],$_SESSION['ntlp'][$_GET['id']],1024);
+$network['source'] = $LMS->GetNetworkRecord($_GET['id'],$SESSION->get('ntlp'.$_GET['id'],1024));
 $network['dest'] = $LMS->GetNetworkRecord($_GET['mapto']);
 
 if($network['source']['assigned'] > $network['dest']['free'])
@@ -40,17 +39,15 @@ if(!$error)
 {
 	if($_GET['is_sure'])
 	{
-
 		$LMS->NetworkRemap($network['source']['id'],$network['dest']['id']);
-		header("Location: ?m=netinfo&id=".$network['dest']['id']);
-		die;
+		$SESSION->redirect('?m=netinfo&id='.$network['dest']['id']);
 
 	}else{
-		$layout['pagetitle'] = "Readresowanie sieci ".strtoupper($network['source']['name']);
+		$layout['pagetitle'] = trans('Readdressing Network $0',strtoupper($network['source']['name']));
 		$SMARTY->display('header.html');
-		echo "<H1>Readresowanie sieci ".strtoupper($network['source']['name'])."</H1>";
-		echo "<p>Jeste pewien e chcesz przeadresowa sie ".strtoupper($network['source']['name'])." (".$network['source']['address']."/".$network['source']['prefix'].") do sieci ".strtoupper($network['dest']['name'])." (".$network['dest']['address']."/".$network['dest']['prefix'].") ?</p>";
-		echo "<a href=\"?m=netremap&id=".$_GET['id']."&mapto=".$_GET['mapto']."&is_sure=1\">Tak, jestem pewien</A>";
+		echo '<H1>'.$layout['pagetitle'].'</H1>';
+		echo '<P>'.trans('Are you sure, you want to readdress network $0 to network $1 ?',strtoupper($network['source']['name']).' ('.$network['source']['address'].'/'.$network['source']['prefix'].')', strtoupper($network['dest']['name']).' ('.$network['dest']['address'].'/'.$network['dest']['prefix'].')').'</P>';
+		echo '<A href="?m=netremap&id='.$_GET['id'].'&mapto='.$_GET['mapto'].'&is_sure=1">'.trans('Yes, I am sure.').'</A>';
 		$SMARTY->display('footer.html');
 	}
 }else{
