@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,38 +21,34 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodedel.php,v 1.25 2004/09/18 19:21:27 alec Exp $
+ *  $Id: nodedel.php,v 1.36.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
-$layout['pagetitle'] = "Usunicie komputera ".$LMS->GetNodeName($_GET['id']);
+$layout['pagetitle'] = trans('Delete Node $0',$LMS->GetNodeName($_GET['id']));
 $SMARTY->assign('nodeid',$_GET['id']);
 
 if (!$LMS->NodeExists($_GET['id']))
 {
-	$body = "<H1>".$layout['pagetitle']."</H1><P>Podany przez Ciebie ID jest bdny bd nie istnieje w bazie danych.</P>";
+	$body = '<P>'.trans('Incorrect ID number').'</P>';
 }else{
 
 	if($_GET['is_sure']!=1)
 	{
-		$body = "<H1>".$layout['pagetitle']."</H1>";
-		$body .= "<P>Czy jeste pewien e chcesz usun komputer ".$LMS->GetNodeName($_GET['id'])."?</P>"; 
-		$body .= "<P><A HREF=\"?m=nodedel&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien.</A></P>";
-		$body .= "<P><A HREF=\"?".$_SESSION['backto']."\">Nie, rozmyliem si.</A></P>";
+		$body = '<P>'.trans('Are you sure, you want to delete node $0?',$LMS->GetNodeName($_GET['id'])).'</P>'; 
+		$body .= '<P><A HREF="?m=nodedel&id='.$_GET['id'].'&is_sure=1">'.trans('Yes, I am sure.').'</A></P>';
 	}else{
 		$owner = $LMS->GetNodeOwner($_GET['id']);
 		$LMS->DeleteNode($_GET['id']);
-		if(isset($_SESSION['backto']))
-			header("Location: ?".$_SESSION['backto']);
+		if($SESSION->is_set('backto'))
+			header('Location: ?'.$SESSION->get('backto'));
 		else
-			header("Location: ?m=userinfo&id=".$owner);
-		$body = "<H1>".$layout['pagetitle']."</H1>";
-		$body .= "<P>Komputer ".$LMS->GetNodeName($_GET['id'])." zosta usunity.</P>";
+			header('Location: ?m=customerinfo&id='.$owner);
+
+		$body = '<P>'.trans('Node $0 was deleted',$LMS->GetNodeName($_GET['id'])).'</P>';
 	}
-		
 }
-$SMARTY->display('header.html');
+
 $SMARTY->assign('body',$body);
 $SMARTY->display('dialog.html');
-$SMARTY->display('footer.html');
 
-?>
\ No newline at end of file
+?>
