@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,46 +21,69 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodelist.php,v 1.32 2004/09/18 19:21:27 alec Exp $
+ *  $Id: nodelist.php,v 1.45.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
-$layout['pagetitle'] = "Lista komputerw";
-
-$_SESSION['backto']=$_SERVER['QUERY_STRING'];
+$layout['pagetitle'] = trans('Nodes List');
 
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 if(!isset($_GET['o']))
-	$o = $_SESSION['nlo'];
+	$SESSION->restore('nlo', $o);
 else
 	$o = $_GET['o'];
-$_SESSION['nlo'] = $o;
+$SESSION->save('nlo', $o);
 
-$nodelist = $LMS->GetNodeList($o);
+if(!isset($_GET['s']))
+	$SESSION->restore('nls', $s);
+else
+	$s = $_GET['s'];
+$SESSION->save('nls', $s);
+
+if(!isset($_GET['n']))
+	$SESSION->restore('nln', $n);
+else
+	$n = $_GET['n'];
+$SESSION->save('nln', $n);
+
+if(!isset($_GET['g']))
+	$SESSION->restore('nlg', $g);
+else
+	$g = $_GET['g'];
+$SESSION->save('nlg', $g);
+
+$nodelist = $LMS->GetNodeList($o, NULL, NULL, $n, $s, $g);
 $listdata['total'] = $nodelist['total'];
 $listdata['order'] = $nodelist['order'];
 $listdata['direction'] = $nodelist['direction'];
 $listdata['totalon'] = $nodelist['totalon'];
 $listdata['totaloff'] = $nodelist['totaloff'];
+$listdata['network'] = $n;
+$listdata['customergroup'] = $g;
+$listdata['state'] = $s;
 
 unset($nodelist['total']);
 unset($nodelist['order']);
 unset($nodelist['direction']);
 unset($nodelist['totalon']);
 unset($nodelist['totaloff']);
-if (isset($_SESSION['nlp']) && !isset($_GET['page']))
-        $_GET['page'] = $_SESSION['nlp'];
+
+if ($SESSION->is_set('nlp') && !isset($_GET['page']))
+	$SESSION->restore('nlp', $_GET['page']);
 	
-$page = (! $_GET['page'] ? 1 : $_GET['page']);
-$pagelimit = (! $LMS->CONFIG['phpui']['nodelist_pagelimit'] ? $listdata['total'] : $LMS->CONFIG['phpui']['nodelist_pagelimit']);
+$page = (!isset($_GET['page']) ? 1 : $_GET['page']);
+$pagelimit = (!isset($CONFIG['phpui']['nodelist_pagelimit']) ? $listdata['total'] : $CONFIG['phpui']['nodelist_pagelimit']);
 $start = ($page - 1) * $pagelimit;
 
-$_SESSION['nlp'] = $page;
+$SESSION->save('nlp', $page);
 
 $SMARTY->assign('page',$page);
 $SMARTY->assign('pagelimit',$pagelimit);
 $SMARTY->assign('start',$start);
 $SMARTY->assign('nodelist',$nodelist);
 $SMARTY->assign('listdata',$listdata);
+$SMARTY->assign('networks',$LMS->GetNetworks());
+$SMARTY->assign('customergroups', $LMS->CustomergroupGetAll());
 $SMARTY->display('nodelist.html');
 
-?>
\ No newline at end of file
+?>
