@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,19 +21,28 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeset.php,v 1.19 2004/09/18 19:21:27 alec Exp $
+ *  $Id: nodeset.php,v 1.31.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
-if($LMS->UserExists($_GET['ownerid']))
+$ownerid = isset($_GET['ownerid']) ? $_GET['ownerid'] : 0;
+$id = isset($_GET['id']) ? $_GET['id'] : 0;
+
+if($ownerid && $LMS->CustomerExists($ownerid))
 {
-	$LMS->NodeSetU($_GET['ownerid'], $_GET['access']);
-	$backid = $_GET['ownerid'];
+	$LMS->NodeSetU($ownerid, isset($_GET['access']) ? 1 : 0);
+
+	$backid = $ownerid;
+	$redir = $SESSION->get('backto');
+	if($SESSION->get('lastmodule')=='customersearch')
+		$redir .= '&search=1';
+
+	$SESSION->redirect('?'.$redir.'#'.$backid);
 }
 
-if($LMS->NodeExists($_GET['id']))
+if($id && $LMS->NodeExists($id))
 {
-	$LMS->NodeSet($_GET['id']);
-	$backid = $_GET['id'];
+	$LMS->NodeSet($id);
+	$backid = $id;
 }
 
 if(isset($_GET['netdev']))
@@ -43,6 +52,6 @@ if(isset($_GET['netdev']))
 		$backid = $_GET['netdev'];
 	}
 
-header("Location: ?".$_SESSION['backto']."#".$backid);
+header('Location: ?'.$SESSION->get('backto').'#'.(isset($backid) ? $backid : ''));
 
 ?>
