@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,49 +21,50 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentadd.php,v 1.6 2004/09/18 19:21:28 alec Exp $
+ *  $Id: paymentadd.php,v 1.16.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
-$payment = $_POST['payment'];
+$payment = isset($_POST['payment']) ? $_POST['payment'] : NULL;
 
-if(isset($payment))
+if($payment)
 {
 	foreach($payment as $key => $value)
 		$payment[$key] = trim($value);
 
-	if($payment['creditor']=="" && $payment['name']=="" && $payment['value']=="")
+	if($payment['creditor']=='' && $payment['name']=='' && $payment['value']=='')
 	{
-		header("Location: ?m=paymentlist");
-		die;
+		$SESSION->redirect('?m=paymentlist');
 	}
 
-	$payment['value'] = str_replace(",",".",$payment['value']);
+	$payment['value'] = str_replace(',','.',$payment['value']);
 
-	if(!(ereg("^[-]?[0-9.,]+$",$payment['value'])))
-		$error['value'] = "Podana warto nie jest poprawna!";
+	if(!(ereg('^[-]?[0-9.,]+$',$payment['value'])))
+		$error['value'] = trans('Incorrect value!');
 
-	if($payment['creditor'] == "")
-		$error['creditor'] = "Musisz poda nazw wierzyciela!";
+	if($payment['creditor'] == '')
+		$error['creditor'] = trans('Creditor name is required!');
 
-	if($payment['name'] == "")
-		$error['name'] = "Musisz poda nazw opaty staej!";
-	else
-		if($LMS->GetPaymentIDByName($payment['name']))
-			$error['name'] = "Istnieje ju opata o nazwie '".$payment['name']."'!";
+	if($payment['name'] == '')
+		$error['name'] = trans('Payment name is required!');
+	elseif($LMS->GetPaymentIDByName($payment['name']))
+		$error['name'] = trans('Specified name is in use!');
 
 	$period = sprintf('%d',$payment['period']);
 	
-	if($period < 0 || $period > 3)
-		$period = 1;
+	if($period < DAILY || $period > YEARLY)
+		$period = MONTHLY;
 
 	switch($period)
 	{
-		case 0:
+		case DAILY:
+			$at = 0;
+		break;
+		case WEEKLY:
 			$at = sprintf('%d',$payment['at']);
 			if($at < 1 || $at > 7)
-				$error['at'] = 'Niepoprawny dzie tygodnia';
+				$error['at'] = trans('Incorrect day of week (1-7)!');
 		break;
-		case 1:
+		case MONTHLY:
 			$at = sprintf('%d',$payment['at']);
 			if($at == 0)
 			{
@@ -72,29 +73,28 @@ if(isset($payment))
 					$at = 1;
 			}
 			if($at < 1 || $at > 28)
-		    		$error['at'] = 'Niepoprawny dzie miesica';
+		    		$error['at'] = trans('Incorrect day of month (1-28)!');
 		break;
-		case 2:
+		case QUARTERLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
-				$error['at'] = 'Niepoprawny format daty';
+				$error['at'] = trans('Incorrect date format!');
 			else {
 				list($d,$m) = split('/',trim($payment['at']));
 				if($d>30 || $d<1)
-					$error['at'] = 'Niepoprawna liczba dni w miesicu';
+					$error['at'] = trans('Incorrect day of month (1-30)!');
 				if($m>3 || $m<1)
-					$error['at'] = 'Niepoprawny numer miesica (max.3)';
+					$error['at'] = trans('Incorrect month number (max.3)!');
 				
 				$at = ($m-1) * 100 + $d;
 			};
 		break;
-		case 3:
+		case YEARLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
-				$error['at'] = 'Niepoprawny format daty';
+				$error['at'] = trans('Incorrect date format!');
 			else
 				list($d,$m) = split('/',trim($payment['at']));
 			$ttime = mktime(12, 0, 0, $m, $d, 1990);
 			$at = date('z',$ttime) + 1;
-			
 		break;	
 	}
 	
@@ -103,10 +103,9 @@ if(isset($payment))
 	if(!$error)
 	{
 		$payment['at'] = $at;
-		if($payment['reuse'] =='')
+		if(isset($payment['reuse']))
 		{
-			header("Location: ?m=paymentlist&id=".$LMS->PaymentAdd($payment));
-			die;
+			$SESSION->redirect('?m=paymentlist&id='.$LMS->PaymentAdd($payment));
 		} else
 			$LMS->PaymentAdd($payment);
 			
@@ -115,10 +114,10 @@ if(isset($payment))
 	}
 }
 
-$layout['pagetitle'] = "Nowa opata staa";
+$layout['pagetitle'] = trans('New Payment');
 
-$SMARTY->assign('error',$error);
-$SMARTY->assign('payment',$payment);
+$SMARTY->assign('error', $error);
+$SMARTY->assign('payment', $payment);
 $SMARTY->display('paymentadd.html');
 
 ?>
