@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentdel.php,v 1.3 2004/09/18 19:21:28 alec Exp $
+ *  $Id: paymentdel.php,v 1.10.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
-if($_GET['is_sure']="1")
+if($_GET['is_sure']=='1')
 	$LMS->PaymentDelete($_GET['id']);	
 
-header("Location: ?m=paymentlist");
-die;
+$SESSION->redirect('?m=paymentlist');
 
 ?>
\ No newline at end of file
