@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,51 +21,54 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentedit.php,v 1.6 2004/09/18 19:21:28 alec Exp $
+ *  $Id: paymentedit.php,v 1.18.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
 if(!$LMS->PaymentExists($_GET['id']))
 {
-	header("Location: ?m=paymentlist");
-	die;
+	$SESSION->redirect('?m=paymentlist');
 }
 
-$payment = $_POST['payment'];
-
-if(isset($payment))
+if(isset($_POST['payment']))
 {
+	$payment = $_POST['payment'];
+	
 	foreach($payment as $key => $value)
 		$payment[$key] = trim($value);
 
-	$payment['value'] = str_replace(",",".",$payment['value']);
+	$payment['value'] = str_replace(',','.',$payment['value']);
 	
-	if($payment['creditor'] == "")
-		$error['creditor'] = "Musisz poda nazw wierzyciela!";
+	if($payment['creditor'] == '')
+		$error['creditor'] = trans('Creditor name is required!');
 
-	if($payment['name'] == "")
-		$error['name'] = "Prosz poda nazw opaty staej!";
+	if($payment['name'] == '')
+		$error['name'] = trans('Payment name is required!');
 	elseif($LMS->GetpaymentIDByName($payment['name']) && $payment['name'] != $LMS->GetPaymentName($_GET['id']))
-		$error['name'] = "Istnieje ju opata o takiej nazwie!";	
+		$error['name'] = trans('Specified name is in use!');	
 
-	if($payment['value'] == "")
-		$error['value'] = "Prosz poda warto!";
-	elseif(!(ereg("^[0-9.,]+$", $payment['value'])))
-		$error['value'] = "Podana warto jest niepoprawna!";
+	if($payment['value'] == '')
+		$error['value'] = trans('Payment value is required!');
+	elseif(!(ereg('^[0-9.,]+$', $payment['value'])))
+		$error['value'] = trans('Incorrect value!');
 
 	$period = sprintf('%d',$payment['period']);
 	
-	if($period < 0 || $period > 3)
-		$period = 1;
+	if($period < DAILY || $period > YEARLY)
+		$period = MONTHLY;
 
 	switch($period)
 	{
-		case 0:
+		case DAILY:
+			$at = 0;
+		break;
+
+		case WEEKLY:
 			$at = sprintf('%d',$payment['at']);
 			if($at < 1 || $at > 7)
-				$error['at'] = 'Niepoprawny dzie tygodnia';
+				$error['at'] = trans('Incorrect day of week (1-7)!');
 		break;
 		
-		case 1:
+		case MONTHLY:
 			$at = sprintf('%d',$payment['at']);
 			if($at == 0)
 			{
@@ -74,26 +77,26 @@ if(isset($payment))
 					$at = 1;
 			}
 			if($at < 1 || $at > 28)
-				$error['at'] = 'Niepoprawny dzie miesica';
+				$error['at'] = trans('Incorrect day of month (1-28)!');
 		break;
 			
-		case 2:
+		case QUARTERLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
-				$error['at'] = 'Niepoprawny format daty';
+				$error['at'] = trans('Incorrect date format!');
 			else {
 				list($d,$m) = split('/',trim($payment['at']));
 				if($d>30 || $d<1)
-					$error['at'] = 'Niepoprawna liczba dni w miesicu';
+					$error['at'] = trans('Incorrect day of month (1-30)!');
 				if($m>3 || $m<1)
-					$error['at'] = 'Niepoprawny numer miesica (max.3)';
+					$error['at'] = trans('Incorrect month number (max.3)!');
 				
 				$at = ($m-1) * 100 + $d;
 			};
 		break;
 		
-		case 3:
+		case YEARLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
-				$error['at'] = 'Niepoprawny format daty';
+				$error['at'] = trans('Incorrect date format!');
 			else
 				list($d,$m) = split('/',trim($payment['at']));
 			$ttime = mktime(12, 0, 0, $m, $d, 1990);
@@ -108,23 +111,24 @@ if(isset($payment))
 	{
 		$payment['at'] = $at;
 		$LMS->PaymentUpdate($payment);
-		header("Location: ?m=paymentinfo&id=".$payment['id']);
-		die;
+		$SESSION->redirect('?m=paymentinfo&id='.$payment['id']);
 	}
 
-} else 
+} 
+else 
 {
 	$payment = $LMS->GetPayment($_GET['id']);
-	if($payment['period']==3)
-		$payment['at'] = date("d/m",($payment['at']-1)*86400);
-	if($payment['period']==2)
-		$payment['at'] = sprintf("%02d/%02d",($payment['at']%100),$payment['at']/100+1);
+
+	if($payment['period'] == YEARLY)
+		$payment['at'] = date('d/m',($payment['at']-1)*86400);
+	if($payment['period'] == QUARTERLY)
+		$payment['at'] = sprintf('%02d/%02d',($payment['at']%100),$payment['at']/100+1);
 }
 	
-$layout['pagetitle'] = "Edycja opaty staej: ".$payment['name'];	
+$layout['pagetitle'] = trans('Payment Edit: $0',$payment['name']);
 
-$SMARTY->assign('payment',$payment);
-$SMARTY->assign('error',$error);
+$SMARTY->assign('payment', $payment);
+$SMARTY->assign('error', $error);
 $SMARTY->display('paymentedit.html');
 
 ?>
