@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,20 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentinfo.php,v 1.6 2004/09/18 19:21:28 alec Exp $
+ *  $Id: paymentinfo.php,v 1.15.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
 if(!$LMS->PaymentExists($_GET['id']))
 {
-	header("Location: ?m=paymentlist");
-	die;
+	$SESSION->redirect('?m=paymentlist');
 }
 
 $payment = $LMS->GetPayment($_GET['id']);
 
-$layout['pagetitle'] = "Informacja o opacie staej: ".$payment['name'];
+$layout['pagetitle'] = trans('Payment Info: $0',$payment['name']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('payment',$payment);
 $SMARTY->display('paymentinfo.html');
