@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentlist.php,v 1.6 2004/09/18 19:21:28 alec Exp $
+ *  $Id: paymentlist.php,v 1.13.2.1 2007/08/17 13:15:26 alec Exp $
  */
 
-$layout['pagetitle'] = "Lista opat staych";
+$layout['pagetitle'] = trans('Payments List');
 
 $paymentlist = $LMS->GetPaymentList();
 
@@ -32,7 +32,7 @@ $listdata['total'] = $paymentlist['total'];
 
 unset($paymentlist['total']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('paymentlist',$paymentlist);
 $SMARTY->assign('listdata',$listdata);
