@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,44 +21,45 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtmessageview.php,v 1.7 2004/09/18 19:21:28 alec Exp $
+ *  $Id: rtmessageview.php,v 1.25.2.1 2007/08/17 13:15:27 alec Exp $
  */
 
-if($filename = $_GET['file'])
+if(isset($_GET['file']))
 {
-	if($attach = $LMS->GetAttachment($_GET['mid'], $filename))
+	$filename = $_GET['file'];
+	if($attach = $DB->GetRow('SELECT * FROM rtattachments WHERE messageid = ? AND filename = ?', array(intval($_GET['mid']), $filename)))
 	{
-		$file = $LMS->CONFIG['rt']['mail_dir'].sprintf("/%06d/%06d/%s",$_GET['tid'],$_GET['mid'],$filename);
+		$file = $CONFIG['rt']['mail_dir'].sprintf("/%06d/%06d/%s",$_GET['tid'],$_GET['mid'],$filename);
 		if(file_exists($file))
 		{
 			$size = @filesize($file);
 			header('Content-Length: '.$size.' bytes');
 			header('Content-Type: '.$attach['contenttype']);
+			header('Cache-Control: private');
 			header('Content-Disposition: attachment; filename='.$filename);
 			@readfile($file);
 		}
+		$SESSION->close();
 		die;
 	}
 }
 
-if(! $_GET['id'])
+if(!isset($_GET['id']))
 {
-	header('Location: ?'.$_SESSION['backto']);
-	die;
+	$SESSION->redirect('?'.$SESSION->get('backto'));
 }
 
-
 $message = $LMS->GetMessage($_GET['id']); 
-if($message['adminid'])
-	$message['adminname'] = $LMS->GetAdminName($message['adminid']);
-
 if($message['userid'])
 	$message['username'] = $LMS->GetUserName($message['userid']);
+
+if($message['customerid'])
+	$message['customername'] = $LMS->GetCustomerName($message['customerid']);
 	
 if(sizeof($message['attachments']))
 	foreach($message['attachments'] as $key => $val) 
 	{
-		list($size, $unit) = setunits(@filesize($LMS->CONFIG['rt']['mail_dir'].sprintf("/%06d/%06d/%s",$message['ticketid'],$message['id'],$val['filename'])));
+		list($size, $unit) = setunits(@filesize($CONFIG['rt']['mail_dir'].sprintf("/%06d/%06d/%s",$message['ticketid'],$message['id'],$val['filename'])));
 		$message['attachments'][$key]['size'] = $size;
 		$message['attachments'][$key]['unit'] = $unit;
 	}
@@ -68,14 +69,14 @@ if($message['inreplyto'])
 	$message['inreplytoid'] = $reply['subject'];
 }
 
-if(!$message['userid'] && !$message['adminid'] && !$message['mailfrom'])
+if(!$message['customerid'] && !$message['userid'] && !$message['mailfrom'])
 {
-	$message['requestor'] = $LMS->DB->GetOne('SELECT requestor FROM rttickets WHERE id=?', array($message['ticketid']));
+	$message['requestor'] = $DB->GetOne('SELECT requestor FROM rttickets WHERE id=?', array($message['ticketid']));
 }
 
-$layout['pagetitle'] = 'Podgld wiadomoci';
+$layout['pagetitle'] = trans('Ticket Review');
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('message', $message);
 $SMARTY->display('rtmessageview.html');
