@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,20 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueinfo.php,v 1.2 2004/09/18 19:21:28 alec Exp $
+ *  $Id: rtqueueinfo.php,v 1.11.2.1 2007/08/17 13:15:27 alec Exp $
  */
 
 if(! $LMS->QueueExists($_GET['id']))
 {
-	header('Location: ?m=rtqueuelist');
-	die;
+	$SESSION->redirect('?m=rtqueuelist');
 }
 
 $queue = $LMS->GetQueue($_GET['id']);
 
-$layout['pagetitle'] = 'Informacje o kolejce: '.$queue['name'];
+$layout['pagetitle'] = trans('Queue Info: $0',$queue['name']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('queue', $queue);
 $SMARTY->display('rtqueueinfo.html');
