@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueuelist.php,v 1.4 2004/09/18 19:21:28 alec Exp $
+ *  $Id: rtqueuelist.php,v 1.12.2.1 2007/08/17 13:15:27 alec Exp $
  */
 
-$layout['pagetitle'] = 'Obsuga zgosze';
+$layout['pagetitle'] = trans('Queues List');
 
 $queues = $LMS->GetQueueList();
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('queues', $queues);
 $SMARTY->display('rtqueuelist.html');
