@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffadd.php,v 1.38 2004/09/18 19:21:28 alec Exp $
+ *  $Id: tariffadd.php,v 1.54.2.1 2007/08/17 13:15:27 alec Exp $
  */
 
 $tariffadd = $_POST['tariffadd'];
@@ -31,20 +31,15 @@ if(isset($tariffadd))
 	foreach($tariffadd as $key => $value)
 		$tariffadd[$key] = trim($value);
 
-	if($tariffadd['name']=='' && $tariffadd['comment']=='' && $tariffadd['value']=='')
+	if($tariffadd['name']=='' && $tariffadd['description']=='' && $tariffadd['value']=='')
 	{
-		header("Location: ?m=tarifflist");
-		die;
+		$SESSION->redirect('Location: ?m=tarifflist');
 	}
 
 	$tariffadd['value'] = str_replace(',','.',$tariffadd['value']);
 
 	if(!(ereg('^[-]?[0-9.,]+$',$tariffadd['value'])))
-		$error['value'] = 'Podana warto taryfy jest niepoprawna!';
-
-	if($tariffadd['taxvalue']!='')
-		if(!(ereg('^[0-9.,]+$',$tariffadd['taxvalue'])) || $tariffadd['taxvalue'] < 0 || $tariffadd['taxvalue'] > 100)
-			$error['taxvalue'] = 'Podana stawka podatku jest niepoprawna!';
+		$error['value'] = trans('Incorrect subscription value!');
 
 	if($tariffadd['uprate']=='') $tariffadd['uprate'] = 0;
 	if($tariffadd['downrate']=='') $tariffadd['downrate'] = 0;
@@ -52,47 +47,52 @@ if(isset($tariffadd))
 	if($tariffadd['downceil']=='') $tariffadd['downceil'] = 0;
 	if($tariffadd['climit']=='') $tariffadd['climit'] = 0;
 	if($tariffadd['plimit']=='') $tariffadd['plimit'] = 0;
+	if($tariffadd['dlimit']=='') $tariffadd['dlimit'] = 0;
 
 	if(!ereg('^[0-9]+$', $tariffadd['uprate']))
-		$error['uprate'] = 'To pole musi zawiera liczb cakowit';
+		$error['uprate'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['downrate']))
-		$error['downrate'] = 'To pole musi zawiera liczb cakowit';
+		$error['downrate'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['upceil']))
-		$error['upceil'] = 'To pole musi zawiera liczb cakowit';
+		$error['upceil'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['downceil']))
-		$error['downceil'] = 'To pole musi zawiera liczb cakowit';
+		$error['downceil'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['climit']))
-		$error['climit'] = 'To pole musi zawiera liczb cakowit';
+		$error['climit'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['plimit']))
-		$error['plimit'] = 'To pole musi zawiera liczb cakowit';
+		$error['plimit'] = trans('Integer value expected!');
+	if(!ereg('^[0-9]+$', $tariffadd['dlimit']))
+		$error['dlimit'] = trans('Integer value expected!');
 
-	if(($tariffadd['uprate'] < 8 || $tariffadd['uprate'] > 4096) && $tariffadd['uprate'] != 0)
-		$error['uprate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
-	if(($tariffadd['downrate'] < 8 || $tariffadd['downrate'] > 4096) && $tariffadd['downrate'] != 0)
-		$error['downrate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
+	if(($tariffadd['uprate'] < 8 || $tariffadd['uprate'] > 10000) && $tariffadd['uprate'] != 0)
+		$error['uprate'] = trans('This field must be within range 8 - 10000');
+	if(($tariffadd['downrate'] < 8 || $tariffadd['downrate'] > 10000) && $tariffadd['downrate'] != 0)
+		$error['downrate'] = trans('This field must be within range 8 - 10000');
 	if(($tariffadd['upceil'] < 8 || $tariffadd['upceil'] < $tariffadd['uprate']) && $tariffadd['upceil'] != 0)
-		$error['upceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od upload rate';
+		$error['upceil'] = trans('This field must contain number greater than 8 and greater than upload rate');
 	if(($tariffadd['downceil'] < 8 || $tariffadd['downceil'] < $tariffadd['downrate']) && $tariffadd['downceil'] != 0)
-		$error['downceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od download rate';
+		$error['downceil'] = trans('This field must contain number greater than 8 and greater than download rate');
 
 	if($tariffadd['name'] == '')
-		$error['name'] = 'Musisz poda nazw taryfy!';
+		$error['name'] = trans('Subscription name required!');
 	else
 		if($LMS->GetTariffIDByName($tariffadd['name']))
-			$error['name'] = "Istnieje ju taryfa o nazwie '".$tariffadd['name']."'!";
+			$error['name'] = trans('Subscription $0 already exists!',$tariffadd['name']);
 
+	if(!isset($tariffadd['taxid']))
+		$tariffadd['taxid'] = 0;
+		
 	if(!$error)
 	{
-		header('Location: ?m=tarifflist&id='.$LMS->TariffAdd($tariffadd));
-		die;
+		$SESSION->redirect('?m=tarifflist&id='.$LMS->TariffAdd($tariffadd));
 	}
-	
 }
 
-$layout['pagetitle'] = 'Nowa taryfa';
+$layout['pagetitle'] = trans('New Subscription');
 
 $SMARTY->assign('error',$error);
 $SMARTY->assign('tariffadd',$tariffadd);
+$SMARTY->assign('taxeslist',$LMS->GetTaxes());
 $SMARTY->display('tariffadd.html');
 
 ?>
