@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,21 +21,26 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffinfo.php,v 1.22 2004/09/18 19:21:28 alec Exp $
+ *  $Id: tariffinfo.php,v 1.34.2.1 2007/08/17 13:15:28 alec Exp $
  */
 
-if(!$LMS->TariffExists($_GET['id']))
+$netid = isset($_GET['netid']) ? intval($_GET['netid']) : NULL;
+
+if(!$LMS->TariffExists($_GET['id']) || ($netid != 0 && !$LMS->NetworkExists($netid)))
 {
-	header("Location: ?m=tarifflist");
-	die;
+	$SESSION->redirect('?m=tarifflist');
 }
-$tariff = $LMS->GetTariff($_GET['id']);
-$layout['pagetitle'] = "Informacja o taryfie: ".$tariff['name'];
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$tariff = $LMS->GetTariff($_GET['id'], $netid);
 
+$layout['pagetitle'] = trans('Subscription Info: $0',$tariff['name']);
+
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
+
+$SMARTY->assign('netid', $netid);
 $SMARTY->assign('tariff',$tariff);
 $SMARTY->assign('tariffs',$LMS->GetTariffs());
+$SMARTY->assign('networks',$LMS->GetNetworks());
 $SMARTY->display('tariffinfo.html');
 
 ?>
