@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,20 +21,20 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tarifflist.php,v 1.25 2004/09/18 19:21:28 alec Exp $
+ *  $Id: tarifflist.php,v 1.33.2.1 2007/08/17 13:15:28 alec Exp $
  */
 
-$layout['pagetitle'] = "Lista taryf";
+$layout['pagetitle'] = trans('Subscription List');
 
 $tarifflist = $LMS->GetTariffList();
 
 $listdata['total'] = $tarifflist['total'];
 $listdata['totalincome'] = $tarifflist['totalincome'];
-$listdata['totalusers'] = $tarifflist['totalusers'];
+$listdata['totalcustomers'] = $tarifflist['totalcustomers'];
 $listdata['totalcount'] = $tarifflist['totalcount'];
 $listdata['totalassignmentcount'] = $tarifflist['totalassignmentcount'];
 
-unset($tarifflist['total'],$tarifflist['totalincome'],$tarifflist['totalusers'],$tarifflist['totalcount'],$tarifflist['totalassignmentcount']);
+unset($tarifflist['total'],$tarifflist['totalincome'],$tarifflist['totalcustomers'],$tarifflist['totalcount'],$tarifflist['totalassignmentcount']);
 
 $SMARTY->assign('tarifflist',$tarifflist);
 $SMARTY->assign('listdata',$listdata);
