@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,14 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: template.php,v 1.21 2004/09/18 19:21:29 alec Exp $
+ *  $Id: template.php,v 1.28.2.1 2007/08/17 13:15:28 alec Exp $
  */
 
-$layout['pagetitle'] = "Tytu moduu";
+$layout['pagetitle'] = trans('Module Title');
+
 $SMARTY->display('header.html');
 
-// Tutaj odpowiednie dziaania
+// module body
 
 $SMARTY->display('footer.html');
 
-?>
\ No newline at end of file
+?>
