@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.5.0 Marduk
+ * LMS version 1.10.2 Roham
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2007 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,21 +21,33 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: welcome.php,v 1.38 2004/09/18 19:21:30 alec Exp $
+ *  $Id: welcome.php,v 1.52.2.1 2007/08/17 13:15:28 alec Exp $
  */
 
-require_once($_LIB_DIR.'/Sysinfo.class.php');
-require_once($_LIB_DIR.'/fortunes.php');
+require_once(LIB_DIR.'/Sysinfo.class.php');
+@include(LIB_DIR.'/locale/'.$_language.'/fortunes.php');
 
 $SI = new Sysinfo;
 
 $layout['pagetitle'] = 'LAN Management System';
 
-$layout['dbversion'] = $LMS->DB->GetDBVersion();
-$layout['dbtype'] = $LMS->CONFIG['database']['type'];
+$layout['dbversion'] = $DB->GetDBVersion();
+$layout['dbtype'] = $CONFIG['database']['type'];
 
+$content = $LMS->CheckUpdates();
+
+if(isset($content['newer_version']))
+{
+	list($v, ) = split(' ', $LMS->_version);
+
+	if(version_compare($content['newer_version'], $v)>0)
+		$SMARTY->assign('newer_version', $content['newer_version']);
+}
+
+$SMARTY->assign('regdata', $LMS->GetRegisterData());
+$SMARTY->assign('rtstats', $LMS->RTStats());
 $SMARTY->assign('sysinfo',$SI->get_sysinfo());
-$SMARTY->assign('userstats',$LMS->UserStats());
+$SMARTY->assign('customerstats',$LMS->CustomerStats());
 $SMARTY->assign('nodestats',$LMS->NodeStats());
 $SMARTY->display('welcome.html');
 
